### ⚙️ **Using Git Submodule**

Instead of manually creating the docker-compose file, you can include it directly from a shared repository:

```bash
git submodule add https://stash.naghashyan.com/scm/ngs/ngs-docker-compose.git docker-compose
```

### ⚠️ **Additional Note:**

If you're checking out the main project from Git, the submodule directory will initially be empty. To fetch the contents of the submodule, you must explicitly initialize and update it with the following command:

```bash
git submodule update --init --recursive
```

After running this command, the submodule's content will become available within your project's directory structure.

---

### 🚀 **Extending the Docker Compose configuration**

To customize the Docker Compose setup specifically for your individual project, create a file named `docker-compose.override.yml` in your project's root directory. Docker Compose automatically merges this file with the main `docker-compose.yml`, allowing you to override or extend any settings.

**Example**: Create `docker-compose.override.yml` to customize your project:

```yaml
version: "3.8"

services:
  app:
    ports:
      - "9090:80"           # Override default web port
    environment:
      MYSQL_PASSWORD: test123   # Override MySQL user password
      XDEBUG_ENABLED: 1         # Enable Xdebug for debugging
      MYSQL_DATABASE: my_project_db  # Custom database name

volumes:
  mysql-data:
    name: my_project_mysql_data  # Custom named volume per project
```

### 📌 **Running the combined configuration (PowerShell script):**

A PowerShell script named `Start-Compose.ps1` is already included in your Docker Compose template repository (`ngsdocker-compose`). This script automatically detects if an override file exists in your project's main directory and runs Docker Compose accordingly.

#### **Executing the PowerShell script:**

Run the script directly from your project root:

```powershell
.\ngsdocker-compose\Start-Compose.ps1
```

This will launch your Docker environment, automatically applying any overrides you've defined.

### 🗑️ **Removing MySQL Volume (PowerShell script):**

A PowerShell script named `Remove-MySQL-Volume.ps1` is also included in the Docker Compose template repository. This script safely removes the Docker volume associated with your project's MySQL data. Use this command if you need to reset your MySQL database:

#### **Executing the PowerShell script to remove MySQL volume:**

Run the script directly from your project root:

```powershell
.\ngsdocker-compose\Remove-MySQL-Volume.ps1
```


