# Start-Compose.ps1
# Runs Docker Compose with base file from current directory and override file from parent project directory (if exists)

# Get absolute paths
$scriptDir = Split-Path -Path $MyInvocation.MyCommand.Definition -Parent
$projectRoot = Split-Path -Path $scriptDir -Parent

$baseCompose = Join-Path $scriptDir "docker-compose.yml"
$overrideCompose = Join-Path $projectRoot "docker-compose.override.yml"

# Move to project root directory
Push-Location $projectRoot

# Check if override file exists
if (Test-Path $overrideCompose) {
    Write-Host "✅ Using override file at: $overrideCompose" -ForegroundColor Green
    docker-compose -f $baseCompose -f $overrideCompose --project-directory $projectRoot up -d
}
else {
    Write-Host "⚠️ Override file not found. Running base compose only." -ForegroundColor Yellow
    docker-compose -f $baseCompose --project-directory $projectRoot up -d
}

# Return back to original directory
Pop-Location